@@ -43,6 +43,9 @@ class WebhookNotification(Resource):
         DisputeOpened = "dispute_opened"
         DisputeLost = "dispute_lost"
         DisputeWon = "dispute_won"
+        DisputeAccepted = "dispute_accepted"
+        DisputeDisputed = "dispute_disputed"
+        DisputeExpired = "dispute_expired"
         GrantorUpdatedGrantedPaymentMethod = "grantor_updated_granted_payment_method"
         RecipientUpdatedGrantedPaymentMethod = "recipient_updated_granted_payment_method"
         GrantedPaymentMethodRevoked = "granted_payment_method_revoked"
